@@ -67,8 +67,6 @@ class SocialMediaGirlsCrawler:
             soup, url_return = await session.get_BS4_and_url(url)
 
             domain = URL("https://" + url.host)
-            if url != url_return:
-                return
 
             title_block = soup.select_one("h1[class=p-title-value]")
             for elem in title_block.find_all("span"):
